
{ config, pkgs, inputs, ... }:

let
    nvidia-offload = pkgs.writeShellScriptBin "nvidia-offload" ''
    export __NV_PRIME_RENDER_OFFLOAD=1
    export __NV_PRIME_RENDER_OFFLOAD_PROVIDER=NVIDIA-G0
    export __GLX_VENDOR_LIBRARY_NAME=nvidia
    export __VK_LAYER_NV_optimus=NVIDIA_only
    exec "$@"
  '';
in
{
  imports =
    [
      ../shared/shared-configuration.nix
      ../shared/desktop-configuration.nix
      ../shared/desktop.nix
      ./ritchie-hardware.nix
      ../shared/filesystem.nix
      ../shared/services/mopidy.nix
    ];

  networking = {
    hostName = "ritchie";
    firewall = {
      enable = false;
    };
  };
  users.users.foxsoft = {
    isNormalUser = true;
    extraGroups = [
      "tmux"
    ];
    openssh.authorizedKeys.keyFiles = [
      ../../users/foxsoft/authorized_keys
    ];
  };

  # Enable the 1Password CLI, this also enables a SGUID wrapper so the CLI can authorize against the GUI app
  programs._1password = {
    enable = true;
  };

  # Enable the 1Passsword GUI with myself as an authorized user for polkit
  programs._1password-gui = {
    enable = true;
  };

  boot.binfmt.emulatedSystems = [
    "aarch64-linux"
  ];
}
